Membrane.MPEG.TS.Muxer.CorruptionError exception
(Membrane MPEG.TS Plugin v2.4.5)
Error raised when the muxer produces corrupted output.
This indicates a critical bug in the underlying mpeg_ts library where packets are being generated with PIDs that were not registered in the PMT, or with invalid/uninitialized memory values.